@@ -6,8 +6,6 @@ if [[ ${COVERAGE:-false} == true ]]; then
     export CXXFLAGS="--coverage"
 fi
 
-echo $PROJ_LIB
-ls $PROJ_LIB/
-make -j${JOBS} test BUILDTYPE=${BUILDTYPE:-Release} V=1
+make -j${JOBS:-1} test BUILDTYPE=${BUILDTYPE:-Release} V=1
 
-set +e +u
\ No newline at end of file
+set +e +u
