@@ -41,11 +41,11 @@ TEST_CASE("decode simple linestring")
     feature.add_geometry(protozero::encode_zigzag32(0));
     
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
     
     SECTION("VT Spec v1") 
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),1);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 1, 0.0, 0.0, 1.0, 1.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "LINESTRING(1 1,2 2,10 10,0 10)");
@@ -54,7 +54,7 @@ TEST_CASE("decode simple linestring")
 
     SECTION("VT Spec v2")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),2);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 2, 0.0, 0.0, 1.0, 1.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "LINESTRING(1 1,2 2,10 10,0 10)");
@@ -72,17 +72,17 @@ TEST_CASE("decode degenerate line_string only moveto")
     feature.add_geometry(protozero::encode_zigzag32(1));
     
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
 
     SECTION("VT Spec v1") 
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),1);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 1, 0.0, 0.0, 1.0, 1.0);
         CHECK( geom.is<mapnik::geometry::geometry_empty>() );
     }
 
     SECTION("VT Spec v2") 
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),2));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 2, 0.0, 0.0, 1.0, 1.0));
     }
 }
 
@@ -100,17 +100,17 @@ TEST_CASE("decode degenerate line_string lineto(0,0)")
     feature.add_geometry(protozero::encode_zigzag32(0));
     
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
 
     SECTION("VT Spec v1") 
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),1);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 1, 0.0, 0.0, 1.0, 1.0);
         CHECK( geom.is<mapnik::geometry::geometry_empty>() );
     }
 
     SECTION("VT Spec v2") 
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),2));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 2, 0.0, 0.0, 1.0, 1.0));
     }
 }
 
@@ -130,11 +130,11 @@ TEST_CASE("decode line_string with first lineto command having delta zero")
     feature.add_geometry(protozero::encode_zigzag32(1));
     
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
     
     SECTION("VT Spec v1") 
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),1);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 1, 0.0, 0.0, 1.0, 1.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "LINESTRING(1 1,2 2)");
@@ -143,7 +143,7 @@ TEST_CASE("decode line_string with first lineto command having delta zero")
 
     SECTION("VT Spec v2")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),2);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 2, 0.0, 0.0, 1.0, 1.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "LINESTRING(1 1,2 2)");
@@ -167,11 +167,11 @@ TEST_CASE("decode line_string with second lineto command having delta zero")
     feature.add_geometry(protozero::encode_zigzag32(0));
     
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
     
     SECTION("VT Spec v1") 
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),1);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 1, 0.0, 0.0, 1.0, 1.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "LINESTRING(1 1,2 2)");
@@ -180,7 +180,7 @@ TEST_CASE("decode line_string with second lineto command having delta zero")
 
     SECTION("VT Spec v2")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),2);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 2, 0.0, 0.0, 1.0, 1.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "LINESTRING(1 1,2 2)");
@@ -206,11 +206,11 @@ TEST_CASE("decode line_string with third lineto command having delta zero")
     feature.add_geometry(protozero::encode_zigzag32(0));
     
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
     
     SECTION("VT Spec v1") 
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),1);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 1, 0.0, 0.0, 1.0, 1.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "LINESTRING(1 1,2 2,3 3)");
@@ -219,7 +219,7 @@ TEST_CASE("decode line_string with third lineto command having delta zero")
 
     SECTION("VT Spec v2")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),2);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 2, 0.0, 0.0, 1.0, 1.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "LINESTRING(1 1,2 2,3 3)");
@@ -243,16 +243,16 @@ TEST_CASE("decode degenerate linestring with close command at end")
     feature.add_geometry(15); // close_path
     
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
     
     SECTION("VT Spec v1")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 1));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 1, 0.0, 0.0, 1.0, 1.0));
     }
 
     SECTION("VT Spec v2")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 2));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 2, 0.0, 0.0, 1.0, 1.0));
     }
 }
 
@@ -272,16 +272,16 @@ TEST_CASE("decode degenerate linestring with close command first")
     feature.add_geometry(protozero::encode_zigzag32(1));
 
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
     
     SECTION("VT Spec v1")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 1));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 1, 0.0, 0.0, 1.0, 1.0));
     }
 
     SECTION("VT Spec v2")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 2));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 2, 0.0, 0.0, 1.0, 1.0));
     }
 }
 
@@ -302,16 +302,16 @@ TEST_CASE("decode degenerate linestring with moveto command count greater then 1
     feature.add_geometry(protozero::encode_zigzag32(1));
     
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
     
     SECTION("VT Spec v1")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 1));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 1, 0.0, 0.0, 1.0, 1.0));
     }
 
     SECTION("VT Spec v2")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 2));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 2, 0.0, 0.0, 1.0, 1.0));
     }
 }
 
@@ -329,16 +329,16 @@ TEST_CASE("decode degenerate linestring with moveto command count of zero")
     feature.add_geometry(protozero::encode_zigzag32(1));
     
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
     
     SECTION("VT Spec v1")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 1));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 1, 0.0, 0.0, 1.0, 1.0));
     }
 
     SECTION("VT Spec v2")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 2));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 2, 0.0, 0.0, 1.0, 1.0));
     }
 }
 
@@ -358,16 +358,16 @@ TEST_CASE("decode degenerate linestring with lineto command count of zero")
     feature.add_geometry(protozero::encode_zigzag32(1));
     
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
     
     SECTION("VT Spec v1")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 1));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 1, 0.0, 0.0, 1.0, 1.0));
     }
 
     SECTION("VT Spec v2")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 2));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 2, 0.0, 0.0, 1.0, 1.0));
     }
 }
 
@@ -386,16 +386,16 @@ TEST_CASE("decode degenerate linestring that starts with unknown command")
     feature.add_geometry(protozero::encode_zigzag32(1));
     
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
     
     SECTION("VT Spec v1")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 1));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 1, 0.0, 0.0, 1.0, 1.0));
     }
 
     SECTION("VT Spec v2")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 2));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 2, 0.0, 0.0, 1.0, 1.0));
     }
 }
 
@@ -414,16 +414,16 @@ TEST_CASE("decode degenerate linestring that ends with unknown command")
     feature.add_geometry((1 << 3u) | 5u); // invalid command
     
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
     
     SECTION("VT Spec v1")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 1));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 1, 0.0, 0.0, 1.0, 1.0));
     }
 
     SECTION("VT Spec v2")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 2));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 2, 0.0, 0.0, 1.0, 1.0));
     }
 }
 
@@ -445,16 +445,16 @@ TEST_CASE("decode degenerate linestring that begins with lineto")
     feature.add_geometry(protozero::encode_zigzag32(1));
     
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
     
     SECTION("VT Spec v1")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 1));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 1, 0.0, 0.0, 1.0, 1.0));
     }
 
     SECTION("VT Spec v2")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 2));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 2, 0.0, 0.0, 1.0, 1.0));
     }
 }
 
@@ -476,16 +476,16 @@ TEST_CASE("decode degenerate linestring that begins with lineto delta zero")
     feature.add_geometry(protozero::encode_zigzag32(1));
     
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
     
     SECTION("VT Spec v1")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 1));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 1, 0.0, 0.0, 1.0, 1.0));
     }
 
     SECTION("VT Spec v2")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 2));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 2, 0.0, 0.0, 1.0, 1.0));
     }
 }
 
@@ -504,16 +504,16 @@ TEST_CASE("decode degenerate linestring that begins with close")
     feature.add_geometry(protozero::encode_zigzag32(1));
     
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
     
     SECTION("VT Spec v1")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 1));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 1, 0.0, 0.0, 1.0, 1.0));
     }
 
     SECTION("VT Spec v2")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 2));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 2, 0.0, 0.0, 1.0, 1.0));
     }
 }
 
@@ -536,11 +536,11 @@ TEST_CASE("decode linestring that begins with two moveto commands")
     feature.add_geometry(protozero::encode_zigzag32(1));
     
     std::string feature_string = feature.SerializeAsString();
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms = feature_to_pbf_geometry<double>(feature_string);
+    mapnik::vector_tile_impl::GeometryPBF geoms = feature_to_pbf_geometry(feature_string);
     
     SECTION("VT Spec v1")
     {
-        auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, feature.type(),1);
+        auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, feature.type(), 1, 0.0, 0.0, 1.0, 1.0);
         std::string wkt0;
         CHECK( test_utils::to_wkt(wkt0,geom) );
         CHECK( wkt0 == "LINESTRING(2 2,3 3)");
@@ -549,6 +549,6 @@ TEST_CASE("decode linestring that begins with two moveto commands")
 
     SECTION("VT Spec v2")
     {
-        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry(geoms, vector_tile::Tile_GeomType_LINESTRING, 2));
+        CHECK_THROWS(mapnik::vector_tile_impl::decode_geometry<double>(geoms, vector_tile::Tile_GeomType_LINESTRING, 2, 0.0, 0.0, 1.0, 1.0));
     }
 }
